/*
 * Common framebuffer server functionality.
 *
 * Copyright (C) 2018, 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#ifdef __cplusplus

#include <l4/devices/fb/framebuffer_interface.h>
#include <l4/re/c/dataspace.h>
#include <l4/sys/types.h>

/* Server object to provide framebuffer data access. */

class Framebuffer_server : public Framebuffer
{
private:
  l4re_ds_t _mem;

protected:
  /* Specialised methods for overriding. */

  virtual l4_size_t _get_framebuffer_size() = 0;
  virtual void _get_view_info(l4re_video_view_info_t *view_info) = 0;

public:
  /* Initialise the server with a capability referencing the exported memory. */

  explicit Framebuffer_server(l4re_ds_t mem)
  : _mem(mem)
  {}

  /* Operation methods. */

  virtual long get_framebuffer(l4_cap_idx_t *mem);
  virtual long get_framebuffer_size(l4_size_t *size);
  virtual long get_view_info(l4re_video_view_info_t *view_info);
};

#endif
